==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/PolarLineSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
/**
 * @hidden
 */
var PolarLineSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesBaseDescriptionMetadata, _super);
    function PolarLineSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarLineSeriesBaseDescriptionMetadata.b = function (a) {
        if (PolarLineSeriesBaseDescriptionMetadata.a == null) {
            PolarLineSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarLineSeriesBaseDescriptionMetadata.c(PolarLineSeriesBaseDescriptionMetadata.a);
        }
        if (a.k(PolarLineSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.ab(PolarLineSeriesBaseDescriptionMetadata.a);
    };
    PolarLineSeriesBaseDescriptionMetadata.c = function (a) {
        PolarBaseDescriptionMetadata.c(a);
    };
    PolarLineSeriesBaseDescriptionMetadata.d = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.b(a);
        a.ac("PolarLineSeriesBase", PolarLineSeriesBaseDescriptionMetadata.a);
    };
    PolarLineSeriesBaseDescriptionMetadata.$t = markType(PolarLineSeriesBaseDescriptionMetadata, 'PolarLineSeriesBaseDescriptionMetadata');
    PolarLineSeriesBaseDescriptionMetadata.a = null;
    return PolarLineSeriesBaseDescriptionMetadata;
}(Base));
export { PolarLineSeriesBaseDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/PolarLineSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarBaseDescriptionMetadata } from "./PolarBaseDescriptionMetadata";
/**
 * @hidden
 */
var PolarLineSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesBaseDescriptionMetadata, _super);
    function PolarLineSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarLineSeriesBaseDescriptionMetadata.b = function (a) {
        if (PolarLineSeriesBaseDescriptionMetadata.a == null) {
            PolarLineSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarLineSeriesBaseDescriptionMetadata.c(PolarLineSeriesBaseDescriptionMetadata.a);
        }
        if (a.k(PolarLineSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.ac(PolarLineSeriesBaseDescriptionMetadata.a);
    };
    PolarLineSeriesBaseDescriptionMetadata.c = function (a) {
        PolarBaseDescriptionMetadata.c(a);
    };
    PolarLineSeriesBaseDescriptionMetadata.d = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.b(a);
        a.ad("PolarLineSeriesBase", PolarLineSeriesBaseDescriptionMetadata.a);
    };
    PolarLineSeriesBaseDescriptionMetadata.$t = markType(PolarLineSeriesBaseDescriptionMetadata, 'PolarLineSeriesBaseDescriptionMetadata');
    PolarLineSeriesBaseDescriptionMetadata.a = null;
    return PolarLineSeriesBaseDescriptionMetadata;
}(Base));
export { PolarLineSeriesBaseDescriptionMetadata };
